@@ -8,7 +8,7 @@ import snow_pyrepl as pyrepl
 from typing import Optional
 from replit.database import Database
 
-__version__ = "1.0.3"
+__version__ = "1.0.5"
 homedir = Path.home()
 homedir = str(homedir).replace("\\", "/")
 __sid__ = open(f"{homedir}/replit-cli/connect.sid", "r").read().strip()
@@ -121,12 +121,18 @@ def push():
 				filelist = glob.glob(f"{newfile}*")
 				typer.echo("Found Sub-Files/Dirs")
 				for file in filelist:
-					files.append(file.replace("\\", "/"))
-					file = file.replace("\\", "/")
-					typer.echo(f"Appending file {file} to list.")
+					if "__pycache__" not in file:
+						files.append(file.replace("\\", "/"))
+						file = file.replace("\\", "/")
+						typer.echo(f"Appending file {file} to list.")
 					if not "." in file:
-						cancontinue = False
-					elif ("." in file or "__pycache__" in file) and file == filelist[-1]:
+						if not "__pycache__" in file:
+							cancontinue = False
+						else:
+							typer.echo("Found Pycache, reached end of list, ending loop...")
+							cancontinue = True
+							break
+					elif file == filelist[-1]:
 						cancontinue = True
 						break
 
